@@ -56,9 +56,9 @@
   #:use-module (rnrs bytevectors)
   #:use-module ((system foreign) #:prefix ffi:)
   #:use-module (srfi srfi-9)
-  #:version (1 00 2))
+  #:version (1 01 1))
 
-(define *ffi-help-version* "1.00.2")
+(define *ffi-help-version* "1.01.1")
 
 (define (sferr fmt . args) (apply simple-format (current-error-port) fmt args))
 
@@ -71,7 +71,7 @@
 ;; The C-based (child) types will add a slot for the object value.
 (define ffi-helper-type
   (make-vtable
-   (string-append standard-vtable-fields "prprpwpw")
+   (string-append standard-vtable-fields "pwpwpwpw")
    (lambda (v p)
      (display "#<ffi-helper-type>" p))))
 (define unwrap-ix 0)
